@@ -1,5 +1,6 @@
-use crate::storage::NodeStorage;
+use crate::storage::Storage;
 
+use async_compat::CompatExt;
 use parking_lot::RwLock;
 use std::fmt;
 use std::thread;
@@ -16,6 +17,12 @@ use smol_timeout::TimeoutExt;
 use systemstat::platform::PlatformImpl;
 use systemstat::{CPULoad, Memory, Platform, System};
 
+pub static PUBLIC_IP_ADDRESS: Lazy<String> = Lazy::new(|| {
+    smol::future::block_on(public_ip::addr().compat())
+        .expect("Could not obtain the public IP address.")
+        .to_string()
+});
+
 // Complete list of metadata endpoints available here: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instancedata-data-categories.html
 const AWS_API_TOKEN_URL: &str = "http://169.254.169.254/latest/api/token";
 
@@ -164,9 +171,7 @@ pub async fn update_aws_information() {
         }
     };
 
-    let mut aws_region_write = AWS_REGION.write();
-
-    *aws_region_write = aws_region;
+    *AWS_REGION.write() = aws_region;
 
     let aws_instance_id_result: Result<String, AWSError> = aws_instance_id().await;
 
@@ -184,7 +189,7 @@ pub async fn update_aws_information() {
     *aws_instance_id_write = aws_instance_id;
 }
 
-pub static GLOBAL_STORAGE: OnceCell<NodeStorage> = OnceCell::new();
+pub static GLOBAL_STORAGE: OnceCell<Storage> = OnceCell::new();
 
 pub static NETWORK: Lazy<RwLock<&str>> = Lazy::new(|| RwLock::new("mainnet"));
 
@@ -440,7 +445,7 @@ fn metrics() -> Result<String, rweb::http::Error> {
 }
 
 fn set_highest_block() {
-    let storage: &NodeStorage = GLOBAL_STORAGE
+    let storage: &Storage = GLOBAL_STORAGE
         .get()
         .expect("Could not get a lock on GLOBAL_STORAGE");
 
@@ -483,15 +488,7 @@ fn set_system_metrics() {
         Ok(uptime) => {
             SYSTEM_UPTIME_SECONDS.set(uptime.as_secs() as i64);
         }
-        Err(error) => log::debug!(
-            "hostname={} public_ip={} network={} region={} instance_id={} There was an error retrieving system uptime: {}",
-            crate::prometheus::HOSTNAME.as_str(),
-            crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-            crate::prometheus::NETWORK.read(),
-            AWS_REGION.read(),
-            AWS_INSTANCE_ID.read(),
-            error
-        ),
+        Err(error) => log::debug!("There was an error retrieving system uptime: {}", error),
     }
 
     let default_network_interface: String = default_net::interface::get_default_interface_name()
@@ -507,12 +504,7 @@ fn set_system_metrics() {
             NETWORK_RECEIVED_BYTES.set(received_bytes as i64);
         }
         Err(error) => log::debug!(
-            "hostname={} public_ip={} network={} region={} instance_id={} There was an error retrieving network traffic information: {}",
-            crate::prometheus::HOSTNAME.as_str(),
-            crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-            crate::prometheus::NETWORK.read(),
-            AWS_REGION.read(),
-            AWS_INSTANCE_ID.read(),
+            "There was an error retrieving network traffic information: {}",
             error
         ),
     }
@@ -533,12 +525,7 @@ fn set_system_metrics() {
             });
         }
         Err(error) => log::debug!(
-            "hostname={} public_ip={} network={} region={} instance_id={} There was an error retrieving filesystem information: {}",
-            crate::prometheus::HOSTNAME.as_str(),
-            crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-            crate::prometheus::NETWORK.read(),
-            AWS_REGION.read(),
-            AWS_INSTANCE_ID.read(),
+            "There was an error retrieving filesystem information: {}",
             error
         ),
     }
@@ -562,14 +549,7 @@ pub async fn prometheus() {
     let three_seconds: time::Duration = time::Duration::from_secs(3);
     Timer::after(three_seconds).await;
 
-    log::debug!(
-        "hostname={} public_ip={} network={} region={} instance_id={} Prometheus metrics listening on http://127.0.0.1:8080",
-        crate::prometheus::HOSTNAME.as_str(),
-        crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-        crate::prometheus::NETWORK.read(),
-        AWS_REGION.read(),
-        AWS_INSTANCE_ID.read()
-    );
+    log::debug!("Prometheus metrics listening on http://127.0.0.1:8080");
 
     REGISTRY
         .register(Box::new(HIGHEST_BLOCK.clone()))
