@@ -1,4 +1,4 @@
-use crate::storage::{MeshaCas, NodeStorage};
+use crate::storage::{MeshaCas, Storage};
 
 use std::{
     net::SocketAddr,
@@ -29,7 +29,7 @@ impl StakerProtocol {
     pub fn new(
         addr: SocketAddr,
         bootstrap: Vec<SocketAddr>,
-        storage: NodeStorage,
+        storage: Storage,
         my_sk: Ed25519SK,
         payout_address: Address,
         target_fee_multiplier: u128,
@@ -56,7 +56,6 @@ impl StakerProtocol {
                     smol::Timer::after(Duration::from_secs(1)).await;
                     // we race the staker loop with epoch termination. epoch termination for now is just a sleep loop that waits until the last block in the epoch is confirmed.
                     let staker_fut = one_epoch_loop(
-                        current_epoch,
                         addr,
                         bootstrap.clone(),
                         storage.clone(),
@@ -85,10 +84,9 @@ impl StakerProtocol {
 }
 
 async fn one_epoch_loop(
-    epoch: u64,
     addr: SocketAddr,
     bootstrap: Vec<SocketAddr>,
-    storage: NodeStorage,
+    storage: Storage,
     my_sk: Ed25519SK,
     payout_covhash: Address,
     target_fee_multiplier: u128,
@@ -150,7 +148,7 @@ async fn one_epoch_loop(
 }
 
 struct StorageBlockBuilder {
-    storage: NodeStorage,
+    storage: Storage,
     payout_covhash: Address,
     target_fee_multiplier: u128,
 }
